import { IRilogMessageConfig } from '../feature/interceptors/message/types';
import { IRilogEventItem } from './events';
import { TRilogPushRequest, TRilogPushResponse } from './requests';
export declare type TOnPushEvent = (event: IRilogEventItem) => void;
export declare type TOnSaveEvents = (event: IRilogEventItem[]) => void;
export interface IRilog {
    init({ key, config }: TRilogInit): void;
    interceptRequestAxios(data: TRilogPushRequest): void;
    interceptResponseAxios(data: TRilogPushResponse): void;
    saveData<T>(data: T, config: IRilogMessageConfig): void;
}
export declare type TRilogInit = {
    key?: string;
    config?: TRilogInitConfig;
};
export declare type TRilogInitConfig = Partial<{
    ignoredRequests: string[];
    sensetiveRequsts: string[];
    sensetiveDataRequests: string[];
    headers: string[];
    localStorage: string[];
    disableFetchInterceptor: boolean;
    disableClickInterceptor: boolean;
    localServer: ILocalServerConfig;
    selfServer: ISelfServer;
    onPushEvent: TOnPushEvent | null;
    onSaveEvents: TOnSaveEvents | null;
}>;
export interface ILocalServerConfig {
    appName: string;
    params?: Record<string, string>;
}
export interface ISelfServer {
    url: string;
    headers?: Record<string, string>;
}
export declare type TInitRequest = {
    uToken: string;
    appId: string;
    externalInfo?: object;
};
export declare type TRilogState = {
    init: boolean;
    token: null | string;
    salt: null | string;
    recording: boolean;
    key: null | string;
    config: null | TRilogInitConfig;
};
export declare type TRilogExtensions = {
    interactivePanel: null | IRilogExtension;
};
export interface IRilogExtension {
    build(): void;
}
export declare type TUpdateStateFn = (state: Partial<TRilogState>) => void;
