"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isFullLocalStorage = exports.megabytesToBytes = exports.getLocalStorageSize = exports.getLocation = exports.getExternalInfo = void 0;
var constants_1 = require("../constants");
var getExternalInfo = function () {
    return {
        userAgent: navigator.userAgent,
    };
};
exports.getExternalInfo = getExternalInfo;
var getLocation = function () {
    var _a, _b;
    return {
        origin: ((_a = window.location) === null || _a === void 0 ? void 0 : _a.origin) || null,
        href: ((_b = window.location) === null || _b === void 0 ? void 0 : _b.href) || null,
    };
};
exports.getLocation = getLocation;
/**
 * Get Local Storage size in bytes.
 * @returns {number}
 */
var getLocalStorageSize = function () {
    var totalSize = 0;
    // Iterate through all items in local storage
    for (var i = 0; i < localStorage.length; i++) {
        var key = localStorage.key(i) || '';
        var value = localStorage.getItem(key) || '';
        // Calculate the size of key and value in bytes
        var keySize = key.length * 2; // Each character is 2 bytes in JavaScript
        var valueSize = value.length * 2 || 1; // Minimum size is 1 byte
        // Add the key and value sizes to the total size
        totalSize += keySize + valueSize;
    }
    // Return the total size in bytes
    return totalSize;
};
exports.getLocalStorageSize = getLocalStorageSize;
/**
 * Simple converter function from megabytes to bytes for defining the max available size of local storage.
 * @param {number} megabytes
 * @returns {number} In bytes
 */
var megabytesToBytes = function (megabytes) {
    var bytesInMegabyte = 1024 * 1024;
    return megabytes * bytesInMegabyte;
};
exports.megabytesToBytes = megabytesToBytes;
var isFullLocalStorage = function (additionalData) {
    if (!additionalData)
        return false;
    var localStorageSize = getLocalStorageSize();
    var additionalDataSize = additionalData.length * 2; // Each character is 2 bytes in JavaScript.
    var maxLocalStorageSize = megabytesToBytes(constants_1.MAX_LOCAL_STORAGE_SIZE);
    if (localStorageSize + additionalDataSize > maxLocalStorageSize)
        return true;
    return false;
};
exports.isFullLocalStorage = isFullLocalStorage;
